%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%   Time-Domain-simulation in irregular seas  %
%     Calculating second order kinematics     %
%---------------------------------------------%
%  Creates linear components from the second  %
%    order surface using Fourier transform    %
%       By: Eivind Bkkedal, 10.06.2014       %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function [zeta_3, seed_3, k_3, omega_3]=Discrete_FFT(zeta_2,seed,omega,zeta_plus,seed_plus,w_plus,zeta_minus,seed_minus,w_minus,t,d,g,w,S,Tp)
L=t(end);
dt=t(end)-t(end-1);
fsHz=1/dt;

%Set up the second order surface
index = 1; 
for tt = 0:dt:L
    zeta_diff1(index)=sum(zeta_minus.*cos(-w_minus.*tt+seed_minus));
    zeta_sum1(index)=sum(zeta_plus.*cos(-w_plus.*tt+seed_plus));
    X(index)=zeta_sum1(index)+zeta_diff1(index)+sum(zeta_2.*cos(-omega.*tt+seed));
   index = index + 1;
end

%Perform the fft with built-in algorithms
N = length(X);
Y = fft(X,N)/N;
zeta_3 = 2*abs(Y(2:N/2))';
seed_3 = -unwrap(angle(Y(2:N/2)))';
faxis = linspace(0,fsHz/2,N/2+1)';
omega_3=2*pi*faxis(2:end-1);

%Introduce a cut frequency of 4wp
ix=find(omega_3>4*2*pi/Tp,1);
omega_3=omega_3(1:ix-1);
seed_3=seed_3(1:ix-1);
zeta_3=zeta_3(1:ix-1);


%Find wave numbers for the new frequency components
for i=1:length(omega_3);
     k_3(i,1)=omega_3(i).^2/g;
     for j=1:20
         k_3(i,1)=omega_3(i).^2/(g*tanh(k_3(i,1)*d));
     end
 end