%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%   Time-Domain-simulation in irregular seas  %
%     Calculating second order kinematics     %
%---------------------------------------------%
%        Compute peaked EAP components        %
%       By: Eivind Bkkedal, 10.06.2014       %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [omega, w1, zeta_a,k,domega]=EAP_p(m0, w, ntot,dw,S,Tn,density,g,d,Hs,plott)
% Setting up initial EAP component
n_peaked=2*round((ntot*density-1)/2)+1;
n_eap=ntot-n_peaked;
w1_temp=zeros(1,ntot+1-n_peaked);
omega_temp=zeros(1,ntot-n_peaked);

%Set up initial EAP component
cut=sqrt(g*2/Hs);
ixx=find(w>cut,1);
m=m0(ixx)/n_eap;
Amp_temp=sqrt(2*m)*ones(1,ntot-n_peaked);

w1_temp(1)=0;
s=0;
j=0;
for i=2:n_eap+1
    while j<(i-1)*m
        s=s+1;
        j=m0(s);
        if s>=length(m0)-1
           break
        end          
    end
    w1_temp(i)=w(s);
    omega_temp(i-1)=(w1_temp(i)+w1_temp(i-1))/2;
end   

%Setting up the peakedness at the eigenfrequency
wn=2*pi/Tn;

[idx, idx] =min(abs(omega_temp-wn));

X1=n_peaked;

if idx==1
    idx_1=idx;
    idx_2=idx+2;
    X=X1+2;
    X_A=(round((X+1)/2))-1;
    X_B=X-X_A;
    B=0;
elseif idx<=2
    idx_1=idx-1;
    idx_2=idx+3;
    X=X1+4;
    X_A=(round((X+1)/2))-1;
    X_B=X-X_A;
    B=0; 
elseif idx < n_eap-2 
    X=X1+5;
    X_A=(round((X+1)/2))-1;
    X_B=X-X_A;
    idx_1=idx-2;
    idx_2=idx+3;
    B=1;  
elseif idx <n_eap
    idx_1=idx-1 ;
    if w1_temp(idx+1)-wn>0.06
        idx_2=idx+1;
        B=0;
        X=X1+2;
        X_A=(round((X+1)/2))-1;
        X_B=X-X_A;
    else
        idx_2=idx+2;
        B=1;
        X=X1+3;
        X_A=(round((X+1)/2))-1;
        X_B=X-X_A;
    end
else
    idx_1=idx;
    idx_2=idx+1;
    B=1;
    X=X1+1;
    X_A=(round((X+1)/2))-1;
    X_B=X-X_A;
end

OMEGA_A=wn-w1_temp(idx_1);
OMEGA_B=w1_temp(idx_2)-wn;
OMG(1)=w1_temp(idx_1);
    
for i=2:X+1
    AA=0;
    if i<X_A+2
        DW(i-1)=OMEGA_A*(X_A+2-i)/(X_A*(X_A+1)/2);
    else
        DW(i-1)=OMEGA_B*(i-B-X_B)/(X_B*(X_B+1)/2);
    end
    OMG(i)=OMG(i-1)+DW(i-1); 
    [idx1 idx1] =min(abs(w-OMG(i-1))); 
    [idx2 idx2] =min(abs(w-OMG(i)));  
    for j=idx1:1:idx2
        AA=AA+S(j)*dw;
    end
    Amp2(i-1)=sqrt(2*AA);
    omega2(i-1)=(OMG(i-1)+DW(i-1)/2);
end

omega=[omega_temp(1:idx_1-1), omega2, omega_temp(idx_2:end)]';
zeta_a=[Amp_temp(1:idx_1-1), Amp2, Amp_temp(idx_2:end)]';
w1=[w1_temp(1:idx_1-1), OMG(1:X), w1_temp(idx_2:end)]';  
domega=w1(2:end)-w1(1:end-1);

 for i=1:length(omega);
     k(i,1)=omega(i).^2/g;
     for j=1:20
         k(i,1)=omega(i).^2/(g*tanh(k(i,1)*d));
     end
 end
 
% plot EAP if applicable, to ensure process gone ok.
if plott==1
figure()
hold on
xlabel('\omega [rad/s]')
ylabel('S(\omega) [m^2s]')
title(['Discretized wavespecter, T_n=',num2str(Tn),', N_t_o_t=',...
    num2str(ntot),', Density=0.1'])
h1=plot(w,S,'k','LineWidth',1.3);
A=[wn wn];
B=[0 70];
h2=plot(A,B,'--b');
for i=1:ntot
    A=[w1(i), w1(i), w1(i+1), w1(i+1)];
    S2(i)=zeta_a(i).^2/(2*(w1(i+1)-w1(i)));
    S1=[0 S2(i) S2(i) 0];
    if i>=(idx_1) && i<(idx_1+X)
        h4=plot(A,S1,'g');
    else
        h3=plot(A,S1,'r');
    end
end
legend([h1 h2 h3 h4],'JONSWAP specter','\omega_n','EAP wave components',...
    'Refined wave components');
    
hold off
end

return


