%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%   Time-Domain-simulation in irregular seas  %
%     Calculating second order kinematics     %
%---------------------------------------------%
% Plotting various comparison between linear  %
%   and second order surface and kinematics   %
%       By: Eivind Bkkedal, 10.06.2014       %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function  [aaa]=Plots(u_3,u_2,u_l,u_t,a_plus,a_minus,u_plus,u_minus, zeta_a,zeta_3, zeta_2,zeta_plus,zeta_minus,k_minus,k_plus,w_minus,w_plus,seed_minus,seed_plus,omega,omega_3,seed,seed_3,k,k_3,d,t,Hs,nz,n);

%Create the history of surface kinematics and elevation
aaa=1;
for i=1:length(t)
    zeta_gauss(i)=sum(zeta_a.*cos(-omega.*t(i)+seed));
    zeta_diff(i)=sum(zeta_minus.*cos(-w_minus.*t(i)+seed_minus));
    zeta_sum(i)=sum(zeta_plus.*cos(-w_plus.*t(i)+seed_plus));
    zeta_second(i)=zeta_sum(i)+zeta_diff(i)+sum(zeta_2.*cos(-omega.*t(i)+seed));
    
    zeta_wheeler(i)=sum(zeta_3.*cos(-omega_3.*t(i)+seed_3));
    if zeta_second(i)<=0
        zz=zeta_second(i);
    else
        zz=0;
    end
    u_gauss(i)=sum(u_l.*cos(-omega.*t(i)+seed));
    u_wheeler(i)=sum(u_3.*cos(-omega_3.*t(i)+seed_3));
    u_diff(i)=sum(u_minus.*cosh(k_minus.*(zz+d))./cosh(k_minus.*d).*cos(-w_minus.*t(i)+seed_minus));
    u_sum(i)=sum(u_plus.*cosh(k_plus.*(zz+d))./cosh(k_plus.*d).*cos(-w_plus.*t(i)+seed_plus));
    u_derive(i)=sum(u_t.*sinh(k.*d)./cosh(k.*d).*cos(-omega.*t(i)+seed)).*max(0,zeta_second(i));
    u_second(i)=u_diff(i)+u_sum(i)+u_derive(i)+sum(u_2.*cosh(k.*(zz+d))./cosh(k.*d).*cos(-omega.*t(i)+seed));
    
    a_gauss(i)=sum(u_l.*omega.*sin(-omega.*t(i)+seed));
    a_wheeler(i)=sum(u_3.*omega_3.*sin(-omega_3.*t(i)+seed_3));
    a_diff(i)=sum(a_minus.*cosh(k_minus.*(zz+d))./cosh(k_minus.*d).*sin(-w_minus.*t(i)+seed_minus));
    a_sum(i)=sum(a_plus.*cosh(k_plus.*(zz+d))./cosh(k_plus.*d).*sin(-w_plus.*t(i)+seed_plus));
    a_derive(i)=sum(u_t.*omega.*sinh(k.*d)./cosh(k.*d).*sin(-omega.*t(i)+seed)).*max(0,zeta_second(i));
    a_second(i)=a_diff(i)+a_sum(i)+a_derive(i)+sum(u_2.*omega.*cosh(k.*(zz+d))./cosh(k.*d).*sin(-omega.*t(i)+seed));
end


%Find maximums
[surfmax,ix]=max(zeta_second);
[umax,ix1]=max(u_second);
[amax,ix2]=max(a_second);

u_corr=u_diff+u_sum;
a_corr=a_diff+a_sum;
zeta_corr=zeta_diff+zeta_sum;

% Plot second order surface profile
figure();
plot(t,zeta_gauss,'b',t,zeta_diff,'-.k',t,zeta_sum,'--k',t,zeta_corr,'k',t,zeta_second,'r');
title('Surface elevation');
legend('Linear','Diff. freq.','Sum freq.','Sum + Diff','2. order','Wheeler 2');
vline(t(ix),'k',['\zeta_2_, _m_a_x=',num2str(round(10*zeta_second(ix))/10)]);
grid on

%Plot second order surface and also show the contributions
figure();
subplot(2,1,1);
plot(t,zeta_gauss,'b',t,zeta_second,'r',t,zeta_corr,'k');
title('Surface elevation');
legend('\zeta_1','\zeta_1+\zeta_2 ','\zeta_2 ');
ylabel('\zeta(t) [m]');
vline(t(ix),'k',['\zeta_m_a_x=',num2str(round(10*surfmax)/10)]);

subplot(2,1,2);
plot(t,zeta_diff,'-.k',t,zeta_sum,'--k',t,zeta_corr,'k');
title('Second order surface corrections');
legend('\zeta_2_,_d_i_f_f','\zeta_2_,_s_u_m ','\zeta_2 ');
ylabel('\zeta(t) [m]');
vline(t(ix),'k',['\zeta_2_, _m_a_x=',num2str(round(10*zeta_corr(ix))/10)]);
ha = axes('Position',[0 0 1 1],'Xlim',[0 1],'Ylim',[0 1],'Box','off',...
    'Visible','off','Units','normalized', 'clipping' , 'off');
text(0.5, 1,['\bf Comparison between surfaces for H_s=',num2str(Hs),'m at ',num2str(d),'m depth'],...
    'HorizontalAlignment' ,'center','VerticalAlignment', 'top')

% Plot second order surface profile and kinematic, compare with linear and second order approximation
figure();
subplot(3,1,1);
plot(t,zeta_gauss,'b',t,zeta_second,'r',t,zeta_corr,'k');
title('Surface elevation');
legend('\zeta_1','\zeta_2 ','\zeta_c_o_r_r ');
ylabel('\zeta(t) [m]');
vline(t(ix),'k',['t=',num2str(t(ix))]);

  subplot(3,1,2);
    plot(t,u_gauss,'b',t,u_wheeler,'c',t,u_second,'r');
    title('Surface Velocity');
    legend('Wheeler linear','Wheeler nonlinear','Stansberg');
    ylabel('u [m/s]')
    vline(t(ix1),'k',['t=',num2str(t(ix1))]);

subplot(3,1,3);
    plot(t,a_gauss,'b',t,a_wheeler,'c',t,a_second,'r');
    title('Free Surface Acceleration');
    legend('Wheeler linear','Wheeler nonlinear','Stansberg');
    xlabel('time [s]')
    ylabel('a [m/s^2]')
    vline(t(ix2),'k',['t=',num2str(t(ix2))]);
ha = axes('Position',[0 0 1 1],'Xlim',[0 1],'Ylim',[0 1],'Box','off',...
    'Visible','off','Units','normalized', 'clipping' , 'off');
text(0.5, 1,['\bf Surface elevation and kinematics for H_s=',num2str(Hs),'m at ',num2str(d),'m depth'],...
    'HorizontalAlignment' ,'center','VerticalAlignment', 'top')

% Plot different contributions to the total second order surface velocity
figure();
plot(t,u_gauss,'b',t,u_diff,'-.k',t,u_sum,'--k',t,u_corr,'k',t,u_derive,'-.g',t,u_second,'r',t,u_wheeler,':r');
title('Horizontal velocity');
legend('Linear','Diff. freq.','Sum freq.','Sum + Diff','u_1','2. order','Wheeler second');
grid on

%Plot kinematic profiles at instant of largest second order kinematics

z_linear=-surfmax-20:(zeta_gauss(ix)+surfmax+20)/(nz-1):zeta_gauss(ix);
z_second=-surfmax-20:(surfmax+surfmax+20)/(nz-1):surfmax;

z_linear_acc=-surfmax-20:(zeta_gauss(ix2)+surfmax+20)/(nz-1):zeta_gauss(ix2);
z_second_acc=-surfmax-20:(zeta_second(ix2)+surfmax+20)/(nz-1):zeta_second(ix2);

for j=1:nz
            u_W(j)=sum(u_l.*cos(-omega.*t(ix)+seed)./cosh(k.*d).*cosh(k.*(d+(z_linear(j)-zeta_gauss(ix))./(1+zeta_gauss(ix)/d))));
            u_W2(j)=sum(u_3.*cos(-omega_3.*t(ix)+seed_3)./cosh(k_3.*d).*cosh(k_3.*((z_second(j)-zeta_second(ix))./(1+zeta_gauss(ix)/d)+d)));
            u_L(j)=sum(u_l.*cos(-omega.*t(ix)+seed)./cosh(k.*d).*cosh(k.*(z_linear(j)+d)));
            u_NL(j)=sum(u_3.*cos(-omega_3.*t(ix)+seed_3)./cosh(k_3.*d).*cosh(k_3.*(z_second(j)+d)));
            u_sumsum(j)=sum(u_plus.*cosh(k_plus.*(z_second(j)+d))./cosh(k_plus.*d).*cos(-w_plus.*t(ix)+seed_plus));
            u_difdif(j)=sum(u_minus.*cosh(k_minus.*(z_second(j)+d))./cosh(k_minus.*d).*cos(-w_minus.*t(ix)+seed_minus));
            u_22(j)=sum(u_2.*cosh(k.*(z_second(j)+d))./cosh(k.*d).*cos(-omega.*t(ix)+seed));
            
            a_W(j)=sum(u_l.*omega.*sin(-omega.*t(ix2)+seed)./cosh(k.*d).*cosh(k.*(d+(z_linear_acc(j)-zeta_gauss(ix2))./(1+zeta_gauss(ix2)/d))));
            a_W2(j)=sum(u_3.*omega_3.*sin(-omega_3.*t(ix2)+seed_3)./cosh(k_3.*d).*cosh(k_3.*((z_second_acc(j)-zeta_second(ix2))./(1+zeta_gauss(ix2)/d)+d)));
            a_L(j)=sum(u_l.*omega.*sin(-omega.*t(ix2)+seed)./cosh(k.*d).*cosh(k.*(z_linear_acc(j)+d)));
            a_NL(j)=sum(u_3.*omega_3.*sin(-omega_3.*t(ix2)+seed_3)./cosh(k_3.*d).*cosh(k_3.*(z_second_acc(j)+d)));
            a_sumsum(j)=sum(u_plus.*w_plus.*cosh(k_plus.*(z_second_acc(j)+d))./cosh(k_plus.*d).*sin(-w_plus.*t(ix2)+seed_plus));
            a_difdif(j)=sum(u_minus.*w_minus.*cosh(k_minus.*(z_second_acc(j)+d))./cosh(k_minus.*d).*sin(-w_minus.*t(ix2)+seed_minus));
            a_22(j)=sum(u_2.*omega.*cosh(k.*(z_second_acc(j)+d))./cosh(k.*d).*sin(-omega.*t(ix2)+seed));
            if z_second(j)<=0
                u_lt(j)=0;
                u_S(j)=u_sumsum(j)+u_difdif(j)+u_22(j);
            else
                u_lt(j)=z_second(j).*sum(u_t.*sinh(k.*d)./cosh(k.*d).*cos(-omega.*t(ix)+seed));
                u_S(j)=sum(u_minus.*cos(-w_minus.*t(ix)+seed_minus))+...
                    sum(u_plus.*cos(-w_plus.*t(ix)+seed_plus))+...
                    sum(u_2.*cos(-omega.*t(ix)+seed))+u_lt(j);
            end
           
              if z_second_acc(j)<=0
                a_lt(j)=0;
                a_S(j)=a_sumsum(j)+a_difdif(j)+a_22(j);
            else
                a_lt(j)=z_second_acc(j).*sum(u_t.*omega.*sinh(k.*d)./cosh(k.*d).*sin(-omega.*t(ix2)+seed));
                a_S(j)=sum(u_minus.*w_minus.*sin(-w_minus.*t(ix2)+seed_minus))+...
                    sum(u_plus.*w_plus.*sin(-w_plus.*t(ix2)+seed_plus))+...
                    sum(u_2.*omega.*sin(-omega.*t(ix2)+seed))+a_lt(j);
            end
            a_Su(j)=a_sumsum(j)+a_difdif(j)+a_22(j);
            u_Su(j)=u_sumsum(j)+u_difdif(j)+u_22(j);
            
        end
        figure();
        plot(u_L,z_linear,'--b',u_W,z_linear,'b',u_NL,z_second,'--c',u_W2,z_second,'c',u_Su,z_second,'--r',u_S,z_second,'r',...
            u_sumsum,z_second,'--k',u_difdif,z_second,'-.k',u_lt,z_second,'k');
        grid on
        title(['Comparison, horizontal velocities at t=',num2str(t(ix))]);
        xlabel('u [m/s]')
        ylabel('depth z [m]')
        legend('Linear \zeta_1','Wheeler \zeta_1','Linear \zeta_2','Wheeler \zeta_2','2. order','Stansberg','\phi_{2,x}^-','\phi_{2,x}^-','\phi_{1,xz}');
        
           figure();
        plot(a_L,z_linear_acc,'--b',a_W,z_linear_acc,'b',a_NL,z_second_acc,'--c',a_W2,z_second_acc,'c',a_Su,z_second_acc,'--r',a_S,z_second_acc,'r',...
            a_sumsum,z_second_acc,'--k',a_difdif,z_second_acc,'-.k',a_lt,z_second_acc,'k');
        grid on
        title(['Comparison, horizontal acceleration at t=',num2str(t(ix2))]);
        xlabel('a [m/s]')
        ylabel('depth z [m]')
        legend('Linear \zeta_1','Wheeler \zeta_1','Linear \zeta_2','Wheeler \zeta_2','2. order','Stansberg','\phi_2_,_x_t^+','\phi_2_,_x_t^-','\phi_1_,_x_t_z');
        
    end