%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%   Time-Domain-simulation in irregular seas  %
%     Calculating second order kinematics     %
%---------------------------------------------%
%Writes gridwave for linear comp. and stretch.%
%       By: Eivind Bkkedal, 10.06.2014       %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function [UU,AA]=Write_gridwave(zeta,seed,k,omega,u_l,t,d,ll,lll)
maxx=max(zeta);
minn=min(zeta);
z=[-90,-60,-40,-30,-25,minn-5,minn-3,minn-2,(minn-1.5):0.1:maxx+0.2];
if lll==1
fid=fopen(['gwf_Gauss',num2str(ll),'.w132'],'w+');
elseif lll==2
    fid=fopen(['gwf_GaussW',num2str(ll),'.w132'],'w+');
end

fprintf(fid,'''\n');
fprintf(fid,'''\n');
fprintf(fid,' GWF Type 132 \n');
fprintf(fid,'''\n');
fprintf(fid,[' GWF   KeyData  Size   1    1     ',num2str(length(z)),'   ', num2str(length(t)),'    1101 \n']);
fprintf(fid,'''\n');
fprintf(fid,'''\n');
fprintf(fid,' GWF   Grid   X   Constant   -2  2 \n');
fprintf(fid,' GWF   Grid   Y   Constant   -2  2 \n');
fprintf(fid,' GWF   Grid   Z   Free    \n');
for i=1:floor(length(z)/14)
    fprintf(fid,' %.1f  ',z((i-1)*14+1:14+(i-1)*14));
    fprintf(fid,'\n');
end
fprintf(fid,' %.1f  ',z((i)*14+1:end));
fprintf(fid,'\n');
fprintf(fid,'''\n');
fprintf(fid,'''\n');
for i=1:length(t)
    fprintf(fid,[' GWF    Time    ',num2str(t(i)),'\n']);
    fprintf(fid,'''\n');
    fprintf(fid,' GWF    Elevation\n');
    fprintf(fid,'''\n');
    fprintf(fid,[' ',num2str(zeta(i)),'\n']);
    fprintf(fid,'''\n');
    
    z_corr=(z-zeta(i))./(1+zeta(i)/d);
    fprintf(fid,' GWF    Velocity \n');
    fprintf(fid,'''\n');
    for j=1:length(z)
        if z_corr(j)<=0
            u(j,1)=sum(u_l.*cosh(k.*(z_corr(j)+d))./cosh(k.*d).*cos(-omega.*t(i)+seed));
        else
            u(j,1)=0;
        end
        u(j,3)=0;
        u(j,2)=0;
        fprintf(fid,' %f ',u(j,:));
        fprintf(fid,'\n');
    end
    
    fprintf(fid,'''\n');
    fprintf(fid,' GWF    Acceleration\n');
    fprintf(fid,'''\n');
    
    for j=1:length(z)
        if z_corr(j)<=0

            a(j,1)=sum(omega.*u_l.*cosh(k.*(z_corr(j)+d))./cosh(k.*d).*sin(-omega.*t(i)+seed));
        else
            a(j,1)=0;
        end
        a(j,3)=0;
        a(j,2)=0;
        fprintf(fid,' %f ',a(j,:));
        fprintf(fid,'\n');
        end
    fprintf(fid,'''\n');
    fprintf(fid,'''\n');
    if ceil(t(i)/10)*10==t(i)
    disp(['time=',num2str(t(i))]);
    end
    
    if max(u(:,1))==max(abs(u(:,1)))
        UU(i)=max(u(:,1));
    else
        UU(i)=-max(abs(u(:,1)));
    end
    if max(a(:,1))==max(abs(a(:,1)))
        AA(i)=max(a(:,1));
    else
        AA(i)=-max(abs(a(:,1)));
    end
   
end

fprintf(fid,''' \n');
fprintf(fid,' GWF    End \n');
fprintf(fid,''' \n');
fprintf(fid,''' \n');
fprintf(fid,''' -------------- e o f --------------');
fclose('all');

