%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%   Time-Domain-simulation in irregular seas  %
%     Calculating second order kinematics     %
%---------------------------------------------%
% Linearizing the wave spectrum, plot results %
%       By: Eivind Bkkedal, 10.06.2014       %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
function [zeta_minus,zeta_plus,zeta_2]=linearizing_spectrum(n,k,R,w_minus,w_plus,D_minus,D_plus,zeta_a,w1,S,w,Hs,Tp,omega,domega,plott)

S_1=zeta_a.^2./2;
S_2=S_1;
%Find the indexes of the second order frequency components which are within each linear "block"
[w_sort_m, sort_m] = sort(abs(w_minus));
[w_sort_p, sort_p] = sort(w_plus);
for i=1:n+1
    ix_p(i)=find(w_sort_p>w1(i),1);
    if w_sort_m(end)>w1(i)
        ix_m(i)=find(w_sort_m>w1(i),1);
    end
end

% Find the correction term, calculate the error made in each block from added variance, remove this from initial linear amplitude, and iterate
for ii=1:3
    jj=1;
    for i=1:n
        if i<n
            zeta_minus(jj:jj+n-i-1,1)=2*1/4*zeta_a(i).*zeta_a(i+1:end).*((D_minus(jj:jj+n-i-1)-(k(i).*k(i+1:end)+R(i).*R(i+1:end)))./sqrt(R(i).*R(i+1:end))+(R(i)+R(i+1:end)));
        end
        zeta_plus(jj:jj+n-i,1)=2*1/4.*zeta_a(i).*zeta_a(i:end).*((D_plus(jj:jj+n-i)-(k(i).*k(i:end)-R(i).*R(i:end)))./sqrt(R(i).*R(i:end))+(R(i)+R(i:end)));
        zeta_plus(jj,1)=zeta_plus(jj,1)/2;
        
        jj=jj+(n-i)+1;
        
    end
    z_sort_m=zeta_minus(sort_m);
    z_sort_p=zeta_plus(sort_p);
    for i=1:n
        if i<=length(ix_m)-1
            if ix_m(i+1)>ix_m(i)
                S_2_m(i,1)=sum(z_sort_m(ix_m(i):ix_m(i+1)-1).^2/2);
            else
                S_2_m(i,1)=0;
            end
        else
            S_2_m(i,1)=0;
        end
        
        if ix_p(i+1)>ix_p(i)
            S_2_p(i,1)=sum(z_sort_p(ix_p(i):ix_p(i+1)-1).^2/2);
            
        else
            S_2_p(i,1)=0;
        end
    end
    ee=(S_2+S_2_p+S_2_m)-S_1;
    S_2=S_2-ee;
    for i=1:n
        if S_2(i)<0
            S_2(i)=0;
            ee(i)=0;
        end
    end
    error=sum(ee);
end

zeta_2=sqrt(S_2*2);
ix=n/2:n:length(w_sort_p)-n/2;

% Can plott the linearized spectrum, if applicable
if plott>=1
    for j=1:length(ix)
        S_2_pp(j,1)=sum(z_sort_p(-n/2+1+ix(j):ix(j)+n/2).^2/(2*(w_sort_p(ix(j)+n/2)-w_sort_p(ix(j)-n/2+1))));
        omega_p(j,1)=mean(w_sort_p(ix(j)-n/2+1:ix(j)+n/2));
    end
    
    figure();
    plot(w,S,'k',omega,S_1./domega,'b',omega,S_2_m./domega,'-.k',omega_p,S_2_pp,'--k',omega,S_2./domega,'r')
    axis([0 w(end) 0 1])
    vline(w1(end),'c',['\omega_c_u_t=',num2str(round(w1(end)*100)/100)]);
    title(['Wave spectrum, zoomed (H_s=',num2str(Hs),' T_p=',num2str(Tp),')'])
    legend('JONSWAP','Linear','Diff. freq.','Sum freq.','2. order');
    figure();
    plot(w,S,'k',omega,S_1./domega,'b',omega,S_2_m./domega,'-.k',omega,S_2_p./domega,'--k',omega,S_2./domega,'r')
    title(['Wave spectrum, zoomed (H_s=',num2str(Hs),' T_p=',num2str(Tp),')'])
    vline(w1(end),'c',['\omega_c_u_t=',num2str(round(w1(end)*100)/100)]);
    legend('JONSWAP','Linear','Diff. freq.','Sum freq.','2. order');
end
