%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%   Time-Domain-simulation in irregular seas  %
%     Calculating second order kinematics     %
%---------------------------------------------%
%    Main script running all other in order   %
%Compare resulting statistics with theoretical%
%       By: Eivind Bkkedal, 10.06.2014       %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

clear all
clc
disp('********************************************');
disp('         Second order wave kinematics       ');
disp('            by: Eivind Bkkedal             ');
disp('********************************************');
global Tn density

Hs=12;
samples=1;
N=10000000;
Tp=14;
g=9.81;
d=90;
Gamma=3.3;
plott=1;
time=200;
dt=0.1;
nz=100;
Tn=9;
density=0.1;
n=100;
t=0:dt:time;

% Parameters defining which method will be used and whether plots or
% gridwave files are written
decomp=2; %1=FFT, 2=EAP, 3=EAP-p
spect=1; %1=JONSWAP, 2=PM
plott=1; %1=plot, 2=gridwave, 3=both

% This value must be given as the point of extreme linear response, with initiation phase, for the combination method. 
%Must be a vector of the same length as the total number simulations
%performed
ix_combo=100;

% In order to use the Both simulation, the seeds of the initial run must be
% stored. A and B can easily be stored as textfiles with dlmwrite, shown-
  A=rand(5000,samples+1)*2*pi;
  B=rand(5000,samples+1);
%dlmwrite('seed1.txt',A)
%dlmwrite('seedB.txt',A) 
% A=load('seed1.txt');
% B=load('seed2.txt');

% run script to assemble the linear components
[zeta_aa,omega,w1,k,domega,S,w, m0,m1,m2,m3,m4, mm, dw]=linear_waves(N, Tp, Hs, Gamma,n, g,d,decomp,spect,plott);

% For all samples, create a random amplitude, and execute the second order calculations. Save statistical values from each run
for i=1:samples
    seed=A(1:length(omega),i);
        for j=1:length(zeta_aa)
            if zeta_aa(j)>0
                zeta_a(j,1)=raylinv(B(j,i),sqrt(zeta_aa(j).^2/2));

            else
                zeta_a(j,1)=zeta_aa(j);

            end
        end
    [zeta_gauss,zeta_second]=second_order(zeta_a,omega,w1,k,seed,g,d,t,domega,Hs,Tp,S,w,nz,i,plott,n,ix_combo(i));
    statistical(i,:)=[max(zeta_gauss), var(zeta_gauss), skewness(zeta_gauss),kurtosis(zeta_gauss),mean(zeta_gauss)];
    statistical_2(i,:)=[max(zeta_second), var(zeta_second), skewness(zeta_second),kurtosis(zeta_second),mean(zeta_second)];
    disp([num2str(i)]);
end


%Calculate statistical parameters from the simulations and compare against theoretical (Forristall and Rayleigh). 
stat=[mean(statistical(:,1)) std(statistical(:,1)) mean(statistical(:,2:end))];
stat2=[mean(statistical_2(:,1)) std(statistical_2(:,1)) mean(statistical_2(:,2:end))];
T_m02=2*pi*sqrt(m0(end)/m2);
T_m01=2*pi*(m0(end)/m1);
nn=(time)/(T_m02);
c_1(1)=Hs/4*(sqrt(2*log(nn))+0.57722/sqrt(2*log(nn)));
c_1(2)=pi/sqrt(6)*Hs/4/sqrt(2*log(nn));
c_1(3)=m0(end);
c_1(4)=0;
c_1(5)=3;
c_1(6)=0;

k1=(2*pi/T_m01).^2/g;
 for j=1:20
      k1=(2*pi/T_m01).^2/(g*tanh(k1*d));
end
s=2*pi*Hs/(g*T_m01^2);
u=Hs/(d^3*k1^2);
af=1/sqrt(8)+0.2892*s+0.1060*u;
bf=2-2.1597*s+0.0968*u^2;

c_2(1)=Hs*af*((log(nn))^(1/bf)+0.57722/(bf*(log(nn))^((bf-1)/bf)));
c_2(2)=pi/sqrt(6)*Hs*af/(bf*(log(nn))^((bf-1)/bf));
c_2(3)=m0(end);
c_2(4)=0;
c_2(5)=0;
c_2(6)=0;

disp('----------------------------- RESULTS ---------------------');
disp(['Theory, 1. order....:   ',num2str(c_1)]);
disp(['100 sim, 1. order...:   ',num2str(stat)]);
disp(['Theory, 2. order....:   ',num2str(c_2)]);
disp(['100 sim, 2. order...:   ',num2str(stat2)]);