%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%   Time-Domain-simulation in irregular seas  %
%     Calculating second order kinematics     %
%---------------------------------------------%
%   Calculates second order correction terms  %
% and executes scripts for specific tasks     %
%       By: Eivind Bkkedal, 10.06.2014       %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

function [zeta_gauss,zeta_second]=second_order(zeta_a,omega,w1,k,seed,g,d,t,domega,Hs,Tp,S,w,nz,ll,plott,n,ix_combo)
R=k.*tanh(k.*d);

%Setting up important values to be used in surface elevation and kinematic calculations, the D's
jj=1;
for i=1:n
    seed_plus(jj:jj+n-i,1)=seed(i)+seed(i:end);
    w_plus(jj:jj+n-i,1)=omega(i)+omega(i:end);
    k_plus(jj:jj+n-i,1)=abs(k(i)+k(i:end));
    denom_plus(jj:jj+n-i,1)=(sqrt(R(i))+sqrt(R(i:end))).^2-k_plus(jj:jj+n-i).*tanh(k_plus(jj:jj+n-i).*d);
    D_plus(jj:jj+n-i,1)=((sqrt(R(i))+sqrt(R(i:end))).*(sqrt(R(i)).*(k(i:end).^2-R(i:end).^2)+sqrt(R(i:end)).*...
        (k(i)^2-R(i)^2))+2.*(sqrt(R(i))+sqrt(R(i:end))).^2.*(k(i).*k(i:end)-R(i).*R(i:end)))./denom_plus(jj:jj+n-i,1);
    if i<n
        seed_minus(jj:jj+n-i-1,1)=seed(i)-seed(i+1:end);
        k_minus(jj:jj+n-i-1,1)=abs(k(i)-k(i+1:end));
        w_minus(jj:jj+n-i-1,1)=omega(i)-omega(i+1:end);
        denom_minus(jj:jj+n-i-1,1)=(sqrt(R(i))-sqrt(R(i+1:end))).^2-k_minus(jj:jj+n-i-1).*tanh(k_minus(jj:jj+n-i-1).*d);
        D_minus(jj:jj+n-i-1,1)=((sqrt(R(i))-sqrt(R(i+1:end))).*(sqrt(R(i+1:end)).*(k(i+1:end).^2-R(i+1:end).^2)-sqrt(R(i+1:end)).*...
            (k(i).^2-R(i).^2))+2.*(sqrt(R(i))-sqrt(R(i+1:end))).^2.*(k(i).*k(i+1:end)+R(i).*R(i+1:end)))./denom_minus(jj:jj+n-i-1);
    end
    jj=jj+(n-i)+1;
end


% Removing round-off errors in matlab creating inf and nan numbers
D_plus(~isfinite(D_plus))=0;
D_minus(~isfinite(D_minus))=0;

% Setting up surface components based on linearizing spectrum
    [zeta_minus,zeta_plus,zeta_2]=linearizing_spectrum(n,k,R,w_minus,w_plus,D_minus,D_plus,zeta_a,w1,S,w,Hs,Tp,omega,domega,plott);
    
% Find the linear components of the second order surface from a fft
    [zeta_3, seed_3, k_3, omega_3]=Discrete_FFT(zeta_2,seed,omega,zeta_plus,seed_plus,w_plus,zeta_minus,seed_minus,w_minus,t,d,g,w,S,Tp);

%Calculate amplitudes for second order kinematics
jj=1;
for i=1:n
    u_plus(jj:jj+n-i,1)=1/2.*k_plus(jj:jj+n-i).*g^2.*zeta_2(i).*zeta_2(i:end)./(omega(i).*omega(i:end)).*D_plus(jj:jj+n-i)./(omega(i)+omega(i:end));
    a_plus(jj:jj+n-i,1)=1/2.*k_plus(jj:jj+n-i).*g^2.*zeta_2(i).*zeta_2(i:end)./(omega(i).*omega(i:end)).*D_plus(jj:jj+n-i);
    
    if i<n
        
        u_minus(jj:jj+n-i-1,1)=-1/2.*k_minus(jj:jj+n-i-1).*g^2.*zeta_2(i).*zeta_2(i+1:end)./(omega(i).*omega(i+1:end)).*D_minus(jj:jj+n-i-1)./(omega(i)-omega(i+1:end));
        a_minus(jj:jj+n-i-1,1)=-1/2.*k_minus(jj:jj+n-i-1).*g^2.*zeta_2(i).*zeta_2(i+1:end)./(omega(i).*omega(i+1:end)).*D_minus(jj:jj+n-i-1);
    end
    u_plus(jj,1)=u_plus(jj,1)/2;
    a_plus(jj,1)=a_plus(jj,1)/2;
    jj=jj+(n-i)+1;
end

%Calculate amplitudes for linear components

u_3=k_3.*g.*zeta_3./omega_3;
u_l=k.*g.*zeta_a./omega;
u_2=k.*g.*zeta_2./omega;
u_t=k.^2.*g.*zeta_2./omega;

%Perform a simulation of the sea profile.
for i=1:length(t)
    zeta_gauss(i)=sum(zeta_a.*cos(-omega.*t(i)+seed));
    zeta_diff(i)=sum(zeta_minus.*cos(-w_minus.*t(i)+seed_minus));
    zeta_sum(i)=sum(zeta_plus.*cos(-w_plus.*t(i)+seed_plus));
    zeta_second(i)=zeta_sum(i)+zeta_diff(i)+sum(zeta_2.*cos(-omega.*t(i)+seed));
    zeta_wheeler(i)=sum(zeta_3.*cos(-omega_3.*t(i)+seed_3));
end

%Plot or write kinematics to gridwave files as applicable

if plott==1;
 [aaa]=Plots(u_3,u_2,u_l,u_t,a_plus,a_minus,u_plus,u_minus, zeta_a,zeta_3, zeta_2,zeta_plus,zeta_minus,k_minus,k_plus,w_minus,w_plus,seed_minus,seed_plus,omega,omega_3,seed,seed_3,k,k_3,d,t,Hs,nz,n);

elseif plott==2
        [UU2,AA2]=Write_gridwave(zeta_gauss,seed,k,omega,u_l,t,d,ll,1);
        [UU4,AA4]=Write_gridwave(zeta_wheeler,seed_3,k_3,omega_3,u_3,t,d,ll,2);
        [UU,AA]=Write_gridwave_NL(zeta_second,seed,k,omega,u_minus,seed_minus,k_minus,w_minus,u_plus,seed_plus,k_plus,w_plus,a_minus,a_plus,u_2,u_t,t,d,ll);
        [UU3,AA3]=Write_gridwave_NL2(zeta_gauss,zeta_second,seed,k,omega,u_minus,seed_minus,k_minus,w_minus,u_plus,seed_plus,k_plus,w_plus,a_minus,a_plus,u_2,u_t,u_l,t,d,ll);
        [UU5,AA5]=Write_gridwave_linear(zeta_gauss,seed,k,omega,u_l,t,d,ll);
 
elseif plott==3
    [aaa]=Plots(u_3,u_2,u_l,u_t,a_plus,a_minus,u_plus,u_minus, zeta_a,zeta_3, zeta_2,zeta_plus,zeta_minus,k_minus,k_plus,w_minus,w_plus,seed_minus,seed_plus,omega,omega_3,seed,seed_3,k,k_3,d,t,Hs,nz,n);
        [UU2,AA2]=Write_gridwave(zeta_gauss,seed,k,omega,u_l,t,d,ll,1);
        [UU4,AA4]=Write_gridwave(zeta_wheeler,seed_3,k_3,omega_3,u_3,t,d,ll,2);
        [UU,AA]=Write_gridwave_NL(zeta_second,seed,k,omega,u_minus,seed_minus,k_minus,w_minus,u_plus,seed_plus,k_plus,w_plus,a_minus,a_plus,u_2,u_t,t,d,ll);
        [UU3,AA3]=Write_gridwave_NL2(zeta_gauss,zeta_second,seed,k,omega,u_minus,seed_minus,k_minus,w_minus,u_plus,seed_plus,k_plus,w_plus,a_minus,a_plus,u_2,u_t,u_l,t,d,ll,ix_combo);
end