%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%   Time-Domain-simulation in irregular seas  %
% Study 3: various methods of simulatinf spect%
%    Main script running all other in order   %
%Compare resulting statistics with theoretical%
%       By: Eivind Bkkedal, 10.06.2014       %
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

Hs=12;
samples=40;
N=10000000;
Tp=14;
d=90;
g=9.81;
Gamma=3.3;
Tmin=4.92;
Tmax=25;
n_fft=[50 100 150 1000];
n_eap=[50 100 150];
init=500;
time=1500;
dt=0.1;
Tn=9;
density=0.2;

if ~exist('Wave_Components')
  mkdir('Wave_Components');
end

% Setting up the JONSWAP or PM specter
 [S, w, m0,m1,m2,m3,m4, mm,dw]=JONSWAP(N, Tp,Tmin,Tmax, Hs, Gamma);
% [S, w, m0,m1,m2,m3,m4,mm dw]=PM(N, Tp,Tmin,Tmax, Hs, Gamma,g);
disp('Set up of spectrum complete')

% Setting up EAP components
for i=1:length(n_eap)
    [omega_EAP(:,i), w1_EAP(:,i), Amp_EAP(:,i)]=EAP(m0, w, n_eap(i),max(n_eap),Tmax,S);
end
disp('Set up of EAP complete');

% % Setting up FFT components with random dw and/or amplitude
for i=1:length(n_fft)
    [omega_FFT(:,i), w1_FFT(:,i), Amp_FFT(:,i)]=FFT(n_fft(i), w, Tmin, Tmax, dw, S,max(n_fft));
end
disp('Set up FFT complete');

% Setting up peaked EAP method for Tn with 4.5 sec.
for i=1:length(n_eap)
    [omega_EAP_p(:,i),w1_EAP_p(:,i),Amp_EAP_p(:,i)]=EAP_p(m0,w,n_eap(i),Tmax,dw,S,max(n_eap),Tn,density);
end
disp('Set up of peaked EAP complete');

rr=rand(5000,200)*2*pi;
t=0:dt:time;

% Statistical extreme waves, Rice/Rayleigh distribution
T_m02=2*pi*sqrt(m0(end)/m2);
c_rice(1)=Hs/4*(sqrt(2*log((time-init)*2/(T_m02)))+0.57722/sqrt(2*log((time-init)*2/(T_m02))));
c_rice(2)=pi/sqrt(6)*sqrt(m0(end))/sqrt(2*log((time-init)*2/(T_m02)));
c_rice(3)=Hs/4*(sqrt(2*log((time-init)/(T_m02)))+0.57722/sqrt(2*log((time-init)/(T_m02))));
c_rice(4)=-Hs/4*(sqrt(2*log((time-init)/(T_m02)))+0.57722/sqrt(2*log((time-init)/(T_m02))));
c_rice(5)=m0(end);
c_rice(6)=mm/(time-init);
c_rice(7)=3;
c_rice(8)=0;
c_rice(9)=0;

disp('========================================================================================')
disp(['  RESULTS, Wave surface statistics, ',num2str(samples),' samples, ',num2str(time-init),'Sim. length' ])
disp(' 0 - regular determ, 1 - random amplitude, 2 - random freq, 3 - random S and w ')
disp('========================================================================================')
disp('-------------- Extreme ----- E. std ---- Max ------- Min ------- var ------- var(var) ----- kurt ------ skew ------ mean')
disp(['Theoretical  : ',num2str(round(10000*c_rice)/10000)]);
disp('---------------------------------------------------------------------------------------------------------')

kk=2;
      rownames(1,1)={'Theory'};
      k=1;
      
% Run surface_realization for FFT comp, save statistics
for ii=0
    if ii==0 || ii==1
        n=length(n_fft);
    else
        n=1:length(n_fft);
    end
    for i=n
        if ~exist(['Wave_Components/FFT_',num2str(ii),'_',num2str(n_fft(i))])
            mkdir(['Wave_Components/FFT_',num2str(ii),'_',num2str(n_fft(i))]);
        end
        for l=1:samples
            seed=A(1:n_fft(i),l);
            [zetaFFT(l+(i-1)*samples,:), zeta_FFT(l+(i-1)*samples,:)]=surface_realization(Amp_FFT(1:n_fft(i),i),omega_FFT(1:n_fft(i),i),w1_FFT(1:n_fft(i)+1,i),seed,t,dt,init,ii,randoms(:,[l samples+l]),l);
            fclose('all');
            movefile([num2str(l),'.txt'],['Wave_Components/FFT_',num2str(ii),'_',num2str(n_fft(i))]);
        end
        zeta_FFT_mean(k,:)=mean(zeta_FFT(1+(i-1)*samples:samples*i,:));
        zeta_FFT_mean(k,2)=std(zeta_FFT(1+(i-1)*samples:samples*i,1));
        zeta_FFT_mean(k,6)=var(zeta_FFT(1+(i-1)*samples:samples*i,5));
        disp(['FFT-',num2str(ii),'-',num2str(n_fft(i)),'      : ',num2str(round(10000*zeta_FFT_mean(k,:))/10000)]);
        rownames(kk,1)={['FFT-',num2str(ii),'-',num2str(n_fft(i))]};
        k=k+1;
        kk=kk+1;
    end
end

% Run surface_realization for EAP comp, save statistics
kkkk=1;
for ii=0:1
    for i=1:length(n_eap)
        if ~exist(['Wave_Components/EAP_',num2str(ii),'_',num2str(n_eap(i))])
            mkdir(['Wave_Components/EAP_',num2str(ii),'_',num2str(n_eap(i))]);
        end
        for l=1:samples
            seed=A(1:n_eap(i),l);
            %Find the instantanous surface elevation
            [zetaEAP(l+(i-1)*samples,:), zeta_EAP(l+(i-1)*samples,:)]=surface_realization(Amp_EAP(1:n_eap(i),i),omega_EAP(1:n_eap(i),i),w1_EAP(1:n_eap(i)+1,i),seed,t,dt,init,ii,randoms(:,[l samples+l]),l);
            fclose('all');
            movefile([num2str(l),'.txt'],['Wave_Components/EAP_',num2str(ii),'_',num2str(n_eap(i))]);
        end
        zeta_EAP_mean(kkkk,:)=mean(zeta_EAP(1+(i-1)*samples:samples*i,:));
        zeta_EAP_mean(kkkk,2)=std(zeta_EAP(1+(i-1)*samples:samples*i,1));
        zeta_EAP_mean(kkkk,6)=var(zeta_EAP(1+(i-1)*samples:samples*i,5));
        disp(['EAP-',num2str(ii),'-',num2str(n_eap(i)),'       : ',num2str(round(10000*zeta_EAP_mean(kkkk,:))/10000)]);
        rownames(kk,1)={['EAP-',num2str(ii),'-',num2str(n_eap(i))]};
        kk=kk+1;
        kkkk=kkkk+1;
    end
end

% Run surface_realization for EAP-p comp, save statistics
kkk=1;
for ii=0:1
    for i=1:length(n_eap)
        if ~exist(['Wave_Components/EAP_p_',num2str(ii),'_',num2str(n_eap(i))])
            mkdir(['Wave_Components/EAP_p_',num2str(ii),'_',num2str(n_eap(i))]);
        end
        for l=1:samples
            seed=A(1:n_eap(i),l);
            %Find the instantanous surface elevation
            [zetaEAP_p(l+(i-1)*samples,:), zeta_EAP_p(l+(i-1)*samples,:)]=surface_realization(Amp_EAP_p(1:n_eap(i),i),omega_EAP_p(1:n_eap(i),i),w1_EAP_p(1:n_eap(i)+1,i),seed,t,dt,init,ii,randoms(:,[l samples+l]),l);
            fclose('all');
            movefile([num2str(l),'.txt'],['Wave_Components/EAP_p_',num2str(ii),'_',num2str(n_eap(i))]);
        end
        zeta_EAP_p_mean(kkk,:)=mean(zeta_EAP_p(1+(i-1)*samples:samples*i,:));
        zeta_EAP_p_mean(kkk,2)=std(zeta_EAP_p(1+(i-1)*samples:samples*i,1));
        zeta_EAP_p_mean(kkk,6)=var(zeta_EAP_p(1+(i-1)*samples:samples*i,5));
        disp(['EAP_p-',num2str(ii),'-',num2str(n_eap(i)),'       : ',num2str(round(10000*zeta_EAP_p_mean(kkk,:))/10000)]);
        rownames(kk,1)={['EAP_p-',num2str(ii),'-',num2str(n_eap(i))]};
        kkk=kkk+1;
        kk=kk+1;
    end
end

% Write surface statistics to excel file

colnames={'AbsMax','Std(AbsMax)','Max','Min','Var','Var(Var)','Kurtoisis','Skewness','Mean'};
xlswrite('Surface Statistic',colnames,1,'B1');
xlswrite('Surface Statistic',rownames,1,'A2');
xlswrite('Surface Statistic',[c_rice; zeta_EAP_p_mean],1,'B2');
xlswrite('Surface Statistic',[c_rice;zeta_FFT_mean;zeta_EAP_mean; zeta_EAP_p_mean],1,'B2');
 